@@ -1,10 +1,9 @@
 import traceback
-from dataclasses import dataclass
 from datetime import datetime, timezone
 import time
 from concurrent.futures import ThreadPoolExecutor, Future
 from boto3.session import Session
-from .context import LogContext
+from codepiper.context import LogContext
 
 
 class BuildMonitor:
