@@ -3,8 +3,9 @@
 import argparse
 import boto3
 
-from .watch import watch_pipeline
-from .rollback import rollback_pipeline
+from codepiper.pipeline_clear import verify_clear
+from codepiper.watch import watch_pipeline
+from codepiper.rollback import rollback_pipeline
 
 
 def process_args():
@@ -42,6 +43,15 @@ def process_args():
         action="store_true",
     )
 
+    verifier = subparsers.add_parser("verify_clear", help="verify pipeline is clear")
+    verifier.set_defaults(func=verify_clear)
+    verifier.add_argument(
+        "-p",
+        "--pipeline",
+        help="Name of the pipeline to verify clear",
+        required=True,
+    )
+
     rollback = subparsers.add_parser(
         "rollback", help="rollback pipeline stage to prior state"
     )
