@@ -6,8 +6,8 @@ import time
 from datetime import datetime, timezone, timedelta
 from dataclasses import dataclass
 from boto3.session import Session
-from .context import LogContextManager
-from .build import BuildMonitor
+from codepiper.context import LogContextManager
+from codepiper.build import BuildMonitor
 
 
 @dataclass
@@ -234,6 +234,7 @@ def watch_pipeline(
     pipeline: str,
     execution_id: str = None,
     follow_logs: bool = False,
+    **kwargs,
 ):
     """Monitor pipeline for new executions and codebuild logs"""
     ctx_mgr = LogContextManager()
